@@ -14,16 +14,15 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import six
+from keystoneauth1 import plugin
 from six.moves import urllib
 
-from keystoneclient import auth
 from keystoneclient import base
 from keystoneclient import exceptions
 
 
 class Tenant(base.Resource):
-    """Represents a Keystone tenant
+    """Represents a Keystone tenant.
 
     Attributes:
         * id: a uuid that identifies the tenant
@@ -32,7 +31,9 @@ class Tenant(base.Resource):
         * enabled: boolean to indicate if tenant is enabled
 
     """
+
     def __repr__(self):
+        """Return string representation of tenant resource information."""
         return "<Tenant %s>" % self._info
 
     def delete(self):
@@ -72,6 +73,7 @@ class Tenant(base.Resource):
 
 class TenantManager(base.ManagerWithFind):
     """Manager class for manipulating Keystone tenants."""
+
     resource_class = Tenant
 
     def __init__(self, client, role_manager, user_manager):
@@ -89,7 +91,7 @@ class TenantManager(base.ManagerWithFind):
                              "enabled": enabled}}
 
         # Allow Extras Passthru and ensure we don't clobber primary arguments.
-        for k, v in six.iteritems(kwargs):
+        for k, v in kwargs.items():
             if k not in params['tenant']:
                 params['tenant'][k] = v
 
@@ -105,7 +107,6 @@ class TenantManager(base.ManagerWithFind):
         :rtype: list of :class:`Tenant`
 
         """
-
         params = {}
         if limit:
             params['limit'] = limit
@@ -122,7 +123,7 @@ class TenantManager(base.ManagerWithFind):
         try:
             tenant_list = self._list('/tenants%s' % query, 'tenants')
         except exceptions.EndpointNotFound:
-            endpoint_filter = {'interface': auth.AUTH_INTERFACE}
+            endpoint_filter = {'interface': plugin.AUTH_INTERFACE}
             tenant_list = self._list('/tenants%s' % query, 'tenants',
                                      endpoint_filter=endpoint_filter)
 
@@ -140,7 +141,7 @@ class TenantManager(base.ManagerWithFind):
             body['tenant']['description'] = description
 
         # Allow Extras Passthru and ensure we don't clobber primary arguments.
-        for k, v in six.iteritems(kwargs):
+        for k, v in kwargs.items():
             if k not in body['tenant']:
                 body['tenant'][k] = v
 
